@@ -3,12 +3,10 @@ import sys
 from pathlib import Path
 from textwrap import dedent
 
-# __all__ is also corrected below.
-__all__ = list("Qt" + body for body in
-    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Designer;Xml;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLWidgets;Pdf;PdfWidgets;Positioning;NetworkAuth;Nfc;Qml;Quick;Quick3D;QuickControls2;QuickWidgets;RemoteObjects;Scxml;Sensors;SerialPort;StateMachine;TextToSpeech;Charts;SpatialAudio;Svg;SvgWidgets;DataVisualization;Bluetooth;UiTools;WebChannel;WebEngineCore;WebEngineWidgets;WebEngineQuick;WebSockets;HttpServer;DBus;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
-    .split(";"))
-__version__ = "6.4.0.1"
-__version_info__ = (6, 4, 0.1, "", "")
+# __all__ is computed below.
+__pre_all__ = ["QtCore", "QtGui", "QtWidgets", "QtPrintSupport", "QtSql", "QtNetwork", "QtTest", "QtConcurrent", "QtDBus", "QtDesigner", "QtXml", "QtHelp", "QtMultimedia", "QtMultimediaWidgets", "QtOpenGL", "QtOpenGLWidgets", "QtPdf", "QtPdfWidgets", "QtPositioning", "QtLocation", "QtNetworkAuth", "QtNfc", "QtQml", "QtQuick", "QtQuick3D", "QtQuickControls2", "QtQuickTest", "QtQuickWidgets", "QtRemoteObjects", "QtScxml", "QtSensors", "QtSerialPort", "QtSerialBus", "QtStateMachine", "QtTextToSpeech", "QtCharts", "QtSpatialAudio", "QtSvg", "QtSvgWidgets", "QtDataVisualization", "QtGraphs", "QtGraphsWidgets", "QtBluetooth", "QtUiTools", "QtWebChannel", "QtWebEngineCore", "QtWebEngineWidgets", "QtWebEngineQuick", "QtWebSockets", "QtHttpServer", "Qt3DCore", "Qt3DRender", "Qt3DInput", "Qt3DLogic", "Qt3DAnimation", "Qt3DExtras"]
+__version__ = "6.8.0.2"
+__version_info__ = (6, 8, 0.2, "", "")
 
 
 def _additional_dll_directories(package_dir):
@@ -97,20 +95,13 @@ def _find_all_qt_modules():
     # Since the wheel split, the __all__ variable cannot be computed statically,
     # because we don't know all modules in advance.
 
-    # Instead, we look into the file system and quickly build a list of all
-    # existing .pyi files, because importing is not desired and also impossible during import.
-    # By using the initially created list, we can keep some order intact.
+    # Instead, we use __getattr__ which is supported since Python 3.7
+    # and create the __all__ list on demand when needed.
     location = Path(__file__).resolve().parent
-
-    # Note: We should _not_ call this function while still building, but use the existing value!
-    in_build = Path("/build/pyside6/src/build") in location.parents
-
-    if in_build:
-        return __all__
-
     files = os.listdir(location)
-    unordered = set(name[:-4] for name in files if name.startswith("Qt") and name.endswith(".pyi"))
-    ordered_part = __all__
+    unordered = set(name[: name.find(".")] for name in files if name.startswith("Qt") and (
+                                                                name.endswith((".pyd", ".so"))))
+    ordered_part = __pre_all__
     result = []
     for name in ordered_part:
         if name in unordered:
@@ -120,5 +111,13 @@ def _find_all_qt_modules():
     return result
 
 
-__all__ = _find_all_qt_modules()
+# Provide the __all__ variable only on access.
+def __getattr__(name: str) -> list[str]:
+    if name == "__all__":
+        global __all__
+        __all__ = _find_all_qt_modules()
+        return __all__
+    raise AttributeError(f"module '{__name__}' has no attribute '{name}' :)")
+
+
 _setupQtDirectories()
